Plotting non colinear dos in VASP — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

Note

Go to the end to download the full example code.

# Plotting non colinear dos in VASP

Plotting non colinear dos in VASP.

First download the example files with the code below. Then replace data_dir below.

Downloading example

     data_dir = pyprocar.download_example(save_dir='',
                                 material='Fe',
                                 code='vasp',
                                 spin_calc_type='non-colinear',
                                 calc_type='dos')

importing pyprocar and specifying local data_dir

    import os

    import pyprocar

    data_dir = os.path.join(
        pyprocar.utils.DATA_DIR, "examples", "Fe", "vasp", "non-colinear", "dos"
    )

## Parametric mode

For details on the meaning of the indices of the atomic projection please refer to the user guide :ref:’atomic_projections’

    atoms = [0]
    orbitals = [4, 5, 6, 7, 8]
    spins = [0]

    pyprocar.dosplot(
        code="vasp",
        mode="parametric",
        fermi=5.5962,
        atoms=atoms,
        orbitals=orbitals,
        clim=[0, 1],
        spins=spins,
        dirname=data_dir,
    )

                --------------------------------------------------------
                There are additional plot options that are defined in a configuration file.
                You can change these configurations by passing the keyword argument to the function
                To print a list of plot options set print_plot_opts=True

                Here is a list modes : plain , parametric , parameteric_line , stack , stack_orbitals , stack_species , overlay , overlay_orbitals , overlay_species
                --------------------------------------------------------

    (<Figure size 900x600 with 2 Axes>, <Axes: xlabel='Energy - E$_F$ (eV)', ylabel='DOS'>)

Total running time of the script: (0 minutes 4.373 seconds)

Gallery generated by Sphinx-Gallery